package cn.unitid.spiderid.detection.view;

import android.Manifest;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.provider.Settings;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.app.AppCompatActivity;
import cn.unitid.spiderid.detection.R;
import permissions.dispatcher.NeedsPermission;
import permissions.dispatcher.OnNeverAskAgain;
import permissions.dispatcher.OnPermissionDenied;
import permissions.dispatcher.OnShowRationale;
import permissions.dispatcher.PermissionRequest;
import permissions.dispatcher.RuntimePermissions;



/**
 * @author : Shiyaozu(Elven)
 * @version : V1.0
 * @date : 2017/12/11
 * @Desc:
 */
@RuntimePermissions
public class LoadingActivity extends AppCompatActivity {

    /**
     * 标记app是否已经获取到需要的权限
     */
    private boolean hasPermission = false;
    private AlertDialog dialog;
    private Handler mHandler;
    private AlertDialog settingDialog;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(getLayoutId());
        mHandler = new Handler();
        checkPermissions();
    }

    public void checkPermissions() {
        LoadingActivityPermissionsDispatcher.requestPermissionsWithPermissionCheck(this);
    }

    /**
     * 请求外部存储的读写权限
     */
    @NeedsPermission({Manifest.permission.WRITE_EXTERNAL_STORAGE,Manifest.permission.CAMERA,
            Manifest.permission.RECORD_AUDIO})
    public void requestPermissions() {
        hasPermission = true;
        mHandler.postDelayed(new Runnable() {
            @Override
            public void run() {
                skipToMain();
            }
        },1000);
    }

    /**
     * 用户拒绝授权
     */
    @OnPermissionDenied({Manifest.permission.WRITE_EXTERNAL_STORAGE,Manifest.permission.CAMERA,
            Manifest.permission.RECORD_AUDIO})
    public void onPermissionRefused() {
        showSettingDialog();
    }

    /**
     * 阐述App获取权限的目的
     *
     * @param request
     */
    @OnShowRationale({Manifest.permission.WRITE_EXTERNAL_STORAGE,Manifest.permission.CAMERA,
            Manifest.permission.RECORD_AUDIO})
    public void showShowRationaleForPermission(final PermissionRequest request) {
        if (dialog == null) {
            dialog = new AlertDialog.Builder(this).create();
            dialog.setMessage(getString(R.string.store_permission_message));
            dialog.setButton(DialogInterface.BUTTON_POSITIVE, getString(R.string.string_allow), new DialogInterface
                    .OnClickListener() {
                @Override
                public void onClick(DialogInterface dialog, int which) {
                    request.proceed();
                }
            });
            dialog.setButton(DialogInterface.BUTTON_NEGATIVE, getString(R.string.string_not_allow), new DialogInterface
                    .OnClickListener() {
                @Override
                public void onClick(DialogInterface dialog, int which) {
                    request.cancel();
                }
            });
            dialog.setCancelable(false);
            dialog.setCanceledOnTouchOutside(false);
            dialog.show();
        } else {
            dialog.show();
        }
    }

    /**
     * 用户勾选了“不再提醒”
     */
    @OnNeverAskAgain({Manifest.permission.WRITE_EXTERNAL_STORAGE,Manifest.permission.CAMERA,
            Manifest.permission.RECORD_AUDIO})
    public void showNeverAskForPermission() {
        showSettingDialog();
    }

    @Override
    public void onRequestPermissionsResult(int requestCode, @NonNull String[] permissions, @NonNull int[] grantResults) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults);
        LoadingActivityPermissionsDispatcher.onRequestPermissionsResult(this, requestCode, grantResults);
    }
    private void showSettingDialog(){
        if (settingDialog == null) {
            settingDialog = new AlertDialog.Builder(this).create();
            settingDialog.setMessage(getString(R.string.string_open_setting_tip));
            settingDialog.setButton(DialogInterface.BUTTON_POSITIVE, getString(R.string.string_goto), new DialogInterface
                    .OnClickListener() {
                @Override
                public void onClick(DialogInterface dialog, int which) {
                    Intent intent =  new Intent(Settings.ACTION_SETTINGS);
                    startActivity(intent);
                    finish();
                }
            });
            settingDialog.setButton(DialogInterface.BUTTON_NEGATIVE, getString(R.string.string_not_goto), new DialogInterface
                    .OnClickListener() {
                @Override
                public void onClick(DialogInterface dialog, int which) {
                    finish();
                }
            });
            settingDialog.setCancelable(false);
            settingDialog.setCanceledOnTouchOutside(false);
            settingDialog.show();
        } else {
            settingDialog.show();
        }
    }

    public int getLayoutId() {
        return R.layout.activity_loading;
    }

    public void skipToMain() {
        startActivity(new Intent(this, MainActivity.class));
        finish();
    }

    @Override
    public void onBackPressed() {
        super.onBackPressed();
        if (hasPermission) {
            getApplication().onTerminate();
        }
    }

    @Override
    protected void onDestroy() {
        if (dialog != null && dialog.isShowing()){
            dialog.cancel();
        }
        if (settingDialog != null && settingDialog.isShowing()){
            settingDialog.cancel();
        }
        mHandler.removeCallbacksAndMessages(null);
        super.onDestroy();
    }
}
