package cn.unitid.spiderid.detection.view;

import android.content.Intent;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

import androidx.annotation.Nullable;
import androidx.appcompat.app.AppCompatActivity;
import cn.unitid.business.view.IdentifyVerifyActivity;
import cn.unitid.liveness.SpiderIdCode;
import cn.unitid.liveness.SpiderIdSdkManager;
import cn.unitid.liveness.constant.SpiderIdConstants;
import cn.unitid.spiderid.detection.R;


/**
 * @author : Shiyaozu(Elven)
 * @version : V1.0
 * @date : 2017/12/12
 * @Desc:
 */
public class MainActivity extends AppCompatActivity implements View.OnClickListener {

    private TextView titleTV;
    private TextView rightTV;
    private EditText authTokenET;
    private EditText enterpriseET;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(getLayoutId());
        titleTV = findViewById(R.id.title_tv);
        titleTV.setText(getName());
        rightTV = findViewById(R.id.right_tv);
        rightTV.setOnClickListener(this);
        rightTV.setText("关于");
        rightTV.setVisibility(View.VISIBLE);
        authTokenET = findViewById(R.id.auth_token);
        enterpriseET = findViewById(R.id.enterprise_auth_token);
    }

    public int getLayoutId() {
        return R.layout.activity_main;
    }


    public String getName() {
        return getString(R.string.main_page_title);
    }

    @Override
    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.right_tv:
                startActivity(new Intent(this, AboutActivity.class));
                break;
            case R.id.verify_personal_info:
                // 个人信息核验
                String authToken = authTokenET.getText().toString().trim();
//                String authToken = "43264e8183bb526c41dc9c5e9139d3dfd591b6cff37683b3e583c72de2b27f25";
                if (TextUtils.isEmpty(authToken)) {
                    Toast.makeText(this, "请输入个人信息认证的authToken", Toast.LENGTH_SHORT).show();
                    return;
                }
                SpiderIdSdkManager.verifyPersonalInfo(this, authToken);

                break;
            case R.id.verify_enterprise_info:
                // 企业信息核验
                String enterpriseAuthToken = enterpriseET.getText().toString().trim();
//                String enterpriseAuthToken = "7d756f719d7ed0fdbfbb37bcdb78db739a15f4397df67da1af05e93abe100cec";
                if (TextUtils.isEmpty(enterpriseAuthToken)) {
                    Toast.makeText(this, "请输入企业信息认证的authToken", Toast.LENGTH_SHORT).show();
                    return;
                }
                SpiderIdSdkManager.verifyEnterprise(this, enterpriseAuthToken);
                break;
            default:
                break;
        }
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
        if (data != null) {
            if (SpiderIdSdkManager.VERIFY_PERSONAL_INFO_REQUEST_CODE == requestCode) {
                // 个人信息核验
                int code = data.getIntExtra(SpiderIdConstants.CODE, -1);
                String message = data.getStringExtra(SpiderIdConstants.MESSAGE);
                if (SpiderIdCode.SUCCESS == code) {
                    // 核验成功
                    Toast.makeText(this, "个人信息认证成功", Toast.LENGTH_LONG).show();
                } else if (SpiderIdCode.MANUAL_AUDIT == code) {
                    // 已提交人工审核
                    Toast.makeText(this, "已进入人工审核", Toast.LENGTH_LONG).show();
                } else if (SpiderIdCode.GET_PAGE_TOKEN_FAILURE == code) {
                    // 获取页面配置信息失败
                    Toast.makeText(this, message, Toast.LENGTH_LONG).show();
                } else if (SpiderIdCode.INVALID_TOKEN == code) {
                    // 无效的token
                    Toast.makeText(this, "无效的token", Toast.LENGTH_LONG).show();
                } else if (SpiderIdCode.CANCEL == code) {
                    // 用户取消操作
                    Toast.makeText(this, "用户取消操作", Toast.LENGTH_LONG).show();
                } else {
                    // 其他失败情况
                    Toast.makeText(this, message, Toast.LENGTH_LONG).show();
                }
            } else if (SpiderIdSdkManager.VERIFY_ENTERPRISE_INFO_REQUEST_CODE == requestCode) {
                // 企业信息核验
                if (data == null) {
                    return;
                }
                int code = data.getIntExtra(SpiderIdConstants.CODE, -1);
                String message = data.getStringExtra(SpiderIdConstants.MESSAGE);
                if (SpiderIdCode.SUCCESS == code) {
                    // 认证完成
                    Toast.makeText(this, "认证完成", Toast.LENGTH_LONG).show();
                } else if (SpiderIdCode.INVALID_TOKEN == code) {
                    // 无效的token
                    Toast.makeText(this, "无效的token", Toast.LENGTH_LONG).show();
                } else if (SpiderIdCode.ACTIONING == code) {
                    // 认证中
                    Toast.makeText(this, "认证中", Toast.LENGTH_LONG).show();
                } else {
                    // 其他失败情况
                    Toast.makeText(this, message, Toast.LENGTH_LONG).show();
                }
            }
        }
        super.onActivityResult(requestCode, resultCode, data);
    }
}
